==> tdesktop-4.8.4-full.tar.gz: tdesktop-4.8.4-full/Telegram/ThirdParty/range-v3/doc/gh-pages/dir_b72dce760dba076c3008801bbd43e21d.js <==
var dir_b72dce760dba076c3008801bbd43e21d =
[
    [ "action", "dir_50daf2a60bc85f4226ffbd3f03a0b5c9.html", "dir_50daf2a60bc85f4226ffbd3f03a0b5c9" ],
    [ "algorithm", "dir_3bcb3f19c2c8a89df408efd863ca1956.html", "dir_3bcb3f19c2c8a89df408efd863ca1956" ],
    [ "experimental", "dir_ab79f1001d8108d9cf2565be4238156b.html", "dir_ab79f1001d8108d9cf2565be4238156b" ],
    [ "functional", "dir_afd20801c8973393a8ff36e168b1f7e8.html", "dir_afd20801c8973393a8ff36e168b1f7e8" ],
    [ "iterator", "dir_78ad3b00ad7f46bee608167e0c5bc196.html", "dir_78ad3b00ad7f46bee608167e0c5bc196" ],
    [ "numeric", "dir_9fbc4ada407f9fbdc73b23d734c40077.html", "dir_9fbc4ada407f9fbdc73b23d734c40077" ],
    [ "range", "dir_a64941c7c2f99399da3603530a0acfbe.html", "dir_a64941c7c2f99399da3603530a0acfbe" ],
    [ "utility", "dir_7e8da53cb0bc1762e5680ccc5286e997.html", "dir_7e8da53cb0bc1762e5680ccc5286e997" ],
    [ "view", "dir_b00b1d9d00cc44a1bf5374fbcb141bf4.html", "dir_b00b1d9d00cc44a1bf5374fbcb141bf4" ],
    [ "action.hpp", "action_8hpp.html", null ],
    [ "algorithm.hpp", "algorithm_8hpp.html", null ],
    [ "all.hpp", "all_8hpp.html", null ],
    [ "compare.hpp", "range_2v3_2compare_8hpp.html", "range_2v3_2compare_8hpp" ],
    [ "core.hpp", "core_8hpp.html", null ],
    [ "functional.hpp", "functional_8hpp.html", null ],
    [ "iterator.hpp", "iterator_8hpp.html", null ],
    [ "numeric.hpp", "numeric_8hpp.html", null ],
    [ "range.hpp", "range_8hpp.html", null ],
    [ "range_for.hpp", "range__for_8hpp.html", null ],
    [ "range_fwd.hpp", "range__fwd_8hpp.html", "range__fwd_8hpp" ],
    [ "utility.hpp", "utility_8hpp.html", null ],
    [ "version.hpp", "version_8hpp.html", null ],
    [ "view.hpp", "view_8hpp.html", null ]
];

==> tdesktop-5.8.3-full.tar.gz: tdesktop-5.8.3-full/Telegram/ThirdParty/range-v3/doc/gh-pages/dir_b72dce760dba076c3008801bbd43e21d.js <==
var dir_b72dce760dba076c3008801bbd43e21d =
[
    [ "action", "dir_50daf2a60bc85f4226ffbd3f03a0b5c9.html", "dir_50daf2a60bc85f4226ffbd3f03a0b5c9" ],
    [ "algorithm", "dir_3bcb3f19c2c8a89df408efd863ca1956.html", "dir_3bcb3f19c2c8a89df408efd863ca1956" ],
    [ "experimental", "dir_ab79f1001d8108d9cf2565be4238156b.html", "dir_ab79f1001d8108d9cf2565be4238156b" ],
    [ "functional", "dir_afd20801c8973393a8ff36e168b1f7e8.html", "dir_afd20801c8973393a8ff36e168b1f7e8" ],
    [ "iterator", "dir_78ad3b00ad7f46bee608167e0c5bc196.html", "dir_78ad3b00ad7f46bee608167e0c5bc196" ],
    [ "numeric", "dir_9fbc4ada407f9fbdc73b23d734c40077.html", "dir_9fbc4ada407f9fbdc73b23d734c40077" ],
    [ "range", "dir_a64941c7c2f99399da3603530a0acfbe.html", "dir_a64941c7c2f99399da3603530a0acfbe" ],
    [ "utility", "dir_7e8da53cb0bc1762e5680ccc5286e997.html", "dir_7e8da53cb0bc1762e5680ccc5286e997" ],
    [ "view", "dir_b00b1d9d00cc44a1bf5374fbcb141bf4.html", "dir_b00b1d9d00cc44a1bf5374fbcb141bf4" ],
    [ "action.hpp", "action_8hpp.html", null ],
    [ "algorithm.hpp", "algorithm_8hpp.html", null ],
    [ "all.hpp", "all_8hpp.html", null ],
    [ "compare.hpp", "range_2v3_2compare_8hpp.html", null ],
    [ "core.hpp", "core_8hpp.html", null ],
    [ "functional.hpp", "functional_8hpp.html", null ],
    [ "iterator.hpp", "iterator_8hpp.html", null ],
    [ "numeric.hpp", "numeric_8hpp.html", null ],
    [ "range.hpp", "range_8hpp.html", null ],
    [ "range_for.hpp", "range__for_8hpp.html", "range__for_8hpp" ],
    [ "range_fwd.hpp", "range__fwd_8hpp.html", "range__fwd_8hpp" ],
    [ "utility.hpp", "utility_8hpp.html", null ],
    [ "version.hpp", "version_8hpp.html", null ],
    [ "view.hpp", "view_8hpp.html", null ]
];
